@@ -19,11 +19,9 @@
 #-# 
  */
 #pragma once
+
 extern void   blowoff_init(void);
-extern void   blowoff_draw(cairo_t *cr);
+extern void   blowoff_draw(void);
 extern void   blowoff_ui(void);
 extern int    BlowOff(void);
-extern void   InitBlowOffFactor(void);
-extern int    do_blowoff(gpointer data);
-
 
