@@ -36,69 +36,85 @@
 #include "blowoff.h"
 #include "wind.h"
 #include "debug.h"
-#include "varia.h"
 
 #define NOTACTIVE \
    (Flags.BirdsOnly || !WorkspaceActive() || Flags.NoSnowFlakes)
 
-int        MaxScrSnowDepth = 0;
-FallenSnow *FsnowFirst = NULL;
 
-static GC EFallenGC;
-static GC FallenGC;
 
 static void   drawquartcircle(int n, short int *y);  // nb: dimension of y > n+1
 static void   CreateSurfaceFromFallen(FallenSnow *f);
-static Pixmap CreatePixmapFromFallen(FallenSnow *f);
 static void   EraseFallenPixel(FallenSnow *fsnow,int x);
 
 void fallensnow_init()
 {
    InitFallenSnow();
-   P(" ");
-   FallenGC      = XCreateGC(display, SnowWin,    0, NULL);
-   EFallenGC     = XCreateGC(display, SnowWin,    0, NULL);  // used to erase fallen snow
+   P(" \n");
 }
 
-void fallensnow_set_gc()
+void UpdateFallenSnowAtBottom()
 {
-   XSetLineAttributes(display, FallenGC, 1, LineSolid,CapRound,JoinMiter);
-   XSetFillStyle( display, EFallenGC, FillSolid);
-   XSetFunction(  display, EFallenGC, GXcopy);
-   XSetForeground(display, EFallenGC, ErasePixel);
+   FallenSnow *fsnow = FindFallen(global.FsnowFirst, 0);
+   if (fsnow)
+      fsnow->y = global.SnowWinHeight;
 }
 
 void fallensnow_draw(cairo_t *cr)
 {
    if (NOTACTIVE)
       return;
-   FallenSnow *fsnow = FsnowFirst;
+   FallenSnow *fsnow = global.FsnowFirst;
    while(fsnow)
    {
       if (HandleFallenSnow(fsnow)) 
       {
-	 P("fallensnow_draw %d\n",
+	 P("fallensnow_draw %d %d\n",counter++,
 	       cairo_image_surface_get_width(fsnow->surface));
+	 P("fallensnow_draw: x:%d y:%d\n",fsnow->x,fsnow->y);
 	 cairo_set_source_surface (cr, fsnow->surface, fsnow->x, fsnow->y-fsnow->h+1);
 	 my_cairo_paint_with_alpha(cr,ALPHA);
+	 fsnow->prevx = fsnow->x;
+	 fsnow->prevy = fsnow->y-fsnow->h+1;
+	 fsnow->prevw = cairo_image_surface_get_width(fsnow->surface);
+	 fsnow->prevh = fsnow->h;
       }
       fsnow = fsnow->next;
    }
 }
 
+void fallensnow_erase()
+{
+   if (NOTACTIVE)
+      return;
+   FallenSnow *fsnow = global.FsnowFirst;
+   while(fsnow)
+   {
+      if (HandleFallenSnow(fsnow)) 
+      {
+	 P("fallensnow_erase %d %d %d %d %d\n",counter++,
+	       fsnow->prevx, fsnow->prevy, fsnow->prevw, fsnow->prevh);
+
+	 myXClearArea(global.display,global.SnowWin,
+	       fsnow->prevx, fsnow->prevy, fsnow->prevw, fsnow->prevh, global.xxposures);
+      }
+      fsnow = fsnow->next;
+   }
+
+}
+
 void fallensnow_ui()
 {
    UIDO(MaxWinSnowDepth   , InitFallenSnow(); ClearScreen(); );
    UIDO(MaxScrSnowDepth   , 
-      SetMaxScreenSnowDepth();
-      InitFallenSnow();
-      ClearScreen();
-      );
+	 SetMaxScreenSnowDepth();
+	 InitFallenSnow();
+	 ClearScreen();
+       );
    UIDO(NoKeepSBot        , InitFallenSnow(); ClearScreen(); );
    UIDO(NoKeepSWin        , InitFallenSnow(); ClearScreen(); );
 }
 
-int do_fallen(UNUSED gpointer data)
+int do_fallen(void *d)
 {
 
    if (Flags.Done)
@@ -106,15 +122,16 @@ int do_fallen(UNUSED gpointer data)
    if (NOTACTIVE)
       return TRUE;
 
-   FallenSnow *fsnow = FsnowFirst;
+   FallenSnow *fsnow = global.FsnowFirst;
    while(fsnow)
    {
       if (HandleFallenSnow(fsnow)) 
 	 DrawFallen(fsnow);
       fsnow = fsnow->next;
    }
-   XFlush(display);
+   XFlush(global.display);
    return TRUE;
+   (void)d;
 }
 
 void drawquartcircle(int n, short int *y)  // nb: dimension of y > n+1
@@ -134,10 +151,13 @@ void PushFallenSnow(FallenSnow **first, WinInfo *win, int x, int y, int w, int h
    p->y          = y;
    p->w          = w;
    p->h          = h;
+   p->prevx      = 0;
+   p->prevy      = 0;
+   p->prevw      = 10;
+   p->prevh      = 10;
    p->w8         = ((w-1)/8+1)*8;
    p->acth       = (short int *)malloc(sizeof(*(p->acth))*w);
    p->desh       = (short int *)malloc(sizeof(*(p->desh))*w);
-   p->clean      = 0;  
    p->surface    = cairo_image_surface_create(CAIRO_FORMAT_ARGB32,w,h);
 
    cairo_t *cr = cairo_create(p->surface);
@@ -185,6 +205,7 @@ int PopFallenSnow(FallenSnow **list)
 // remove by id
 int RemoveFallenSnow(FallenSnow **list, Window id)
 {
+   P("RemoveFallenSnow\n");
    if (*list == NULL)
       return 0;
 
@@ -244,77 +265,41 @@ void PrintFallenSnow(FallenSnow *list)
       int i;
       for(i=0; i<fallen->w; i++)
 	 sumact += fallen->acth[i];
-      printf("id:%#10lx ws:%4d x:%6d y:%6d w:%6d cln:%2d sty:%2d hid:%2d sum:%8d\n", fallen->win.id, fallen->win.ws,
-	    fallen->x, fallen->y, fallen->w, fallen->clean, fallen->win.sticky, fallen->win.hidden, sumact);
+      printf("id:%#10lx ws:%4d x:%6d y:%6d w:%6d sty:%2d hid:%2d sum:%8d\n", fallen->win.id, fallen->win.ws,
+	    fallen->x, fallen->y, fallen->w, fallen->win.sticky, fallen->win.hidden, sumact);
       fallen = fallen->next;
    }
 }
 
 void CleanFallenArea(FallenSnow *fsnow,int xstart,int w)
 {
-   if(switches.UseGtk)
+   if(global.IsDouble)
       return;
-   if(fsnow->clean) 
-      return;
-   int x = fsnow->x;
-   int y = fsnow->y - fsnow->h;
-   if(switches.Trans|Flags.UseBG)
-      XFillRectangle(display, SnowWin,  EFallenGC, x+xstart,y,
-	    w, fsnow->h+MaxSnowFlakeHeight);
-   else
-      XClearArea(display, SnowWin, x+xstart, y, w, fsnow->h+MaxSnowFlakeHeight, switches.Exposures);
-   if(xstart <= 0 && w >= fsnow->w)
-      fsnow->clean = 1;
+   P("CleanFallenArea %d %d\n",counter++,global.IsDouble);
+   int x = fsnow->prevx;
+   int y = fsnow->prevy;
+   myXClearArea(global.display, global.SnowWin, x+xstart, y, w, fsnow->h+global.MaxSnowFlakeHeight, global.xxposures);
 }
 
 // clean area for fallensnow with id
 void CleanFallen(Window id)
 {
-   FallenSnow *fsnow = FsnowFirst;
+   P("CleanFallen %#lx\n",id);
+   FallenSnow *fsnow = global.FsnowFirst;
    // search the id
    while(fsnow)
    {
       if(fsnow->win.id == id)
       {
 	 CleanFallenArea(fsnow,0,fsnow->w);
+	 //myXClearArea(global.display,global.SnowWin,
+	 //     fsnow->prevx, fsnow->prevy, fsnow->prevw, fsnow->prevh, global.xxposures);
 	 break;
       }
       fsnow = fsnow->next;
    }
 }
 
-Pixmap CreatePixmapFromFallen(FallenSnow *f)
-{
-   // todo: takes too much cpu
-   int j;
-   int p = 0;
-   // malloc((1+ ...) to be sure we are allocating at least 1 byte
-   unsigned char *bitmap = (unsigned char *) malloc((1+f->w8*f->h/8)*sizeof(unsigned char));
-
-   for (j=0; j<f->h; j++)
-   {
-      int i;
-      for (i=0; i<f->w8; i+=8)
-      {
-	 int b = 0;
-	 int m = 1;
-	 int k;
-	 int kmax = i+8;
-	 if (kmax > f->w) kmax = f->w;
-	 for (k=i; k<kmax; k++)
-	 {
-	    if(f->acth[k] >= f->h-j)
-	       b |= m;
-	    m <<= 1;
-	 }
-	 bitmap[p++] = b;
-      }
-   }
-   Pixmap pixmap = XCreateBitmapFromData(display, SnowWin, (char *)bitmap, f->w, f->h);
-   free(bitmap);
-   return pixmap;
-}
-
 void CreateSurfaceFromFallen(FallenSnow *f)
 {
    P("createsurface %#10lx %d %d %d %d %d %d\n",f->id,f->x,f->y,f->w,f->h,
@@ -347,56 +332,38 @@ void CreateSurfaceFromFallen(FallenSnow *f)
 
 void DrawFallen(FallenSnow *fsnow)
 {
-   if(!fsnow->clean)
-      if(fsnow->win.id == 0 || (!fsnow->win.hidden &&
-	       (fsnow->win.ws == CWorkSpace || fsnow->win.sticky)))
+   if(fsnow->win.id == 0 || (!fsnow->win.hidden &&
+	    (fsnow->win.ws == global.CWorkSpace || fsnow->win.sticky)))
+   {
+      // do not interfere with Santa
+      if(!Flags.NoSanta)
       {
-	 // do not interfere with Santa
-	 if(!Flags.NoSanta)
+	 int in = XRectInRegion(global.SantaPlowRegion, fsnow->x, fsnow->y - fsnow->h,
+	       fsnow->w, fsnow->h);
+	 if (in == RectangleIn || in == RectanglePart)
 	 {
-	    int in = XRectInRegion(SantaPlowRegion, fsnow->x, fsnow->y - fsnow->h,
-		  fsnow->w, fsnow->h);
-	    if (in == RectangleIn || in == RectanglePart)
-	    {
-	       // determine front of Santa in fsnow
-	       int xfront = SantaX+SantaWidth - fsnow->x;
-	       // determine back of Santa in fsnow, Santa can move backwards in strong wind
-	       int xback = xfront - SantaWidth;
-	       const int clearing = 1;
-	       float vy = -1.5*ActualSantaSpeed; 
-	       if(vy > 0) vy = -vy;
-	       if (vy < -100.0)
-		  vy = -100;
-	       if (ActualSantaSpeed > 0)
-		  GenerateFlakesFromFallen(fsnow,xfront,clearing,vy);
-	       CleanFallenArea(fsnow,xback-clearing,SantaWidth+2*clearing);
-	       int i;
-	       for (i=0; i<fsnow->w; i++)
-		  if (i < xfront+clearing && i>=xback-clearing)
-		     fsnow->acth[i] = 0;
-	       XFlush(display);
-	    }
-	 }
-	 if(switches.UseGtk)
-	 {
-	    CreateSurfaceFromFallen(fsnow);
-	    // drawing is handled in fallensnow-draw
-	 }
-	 else
-	 {
-	    Pixmap pixmap = CreatePixmapFromFallen(fsnow);
-	    XSetStipple(display, FallenGC, pixmap);
-	    XFreePixmap(display,pixmap);
-	    int x = fsnow->x;
-	    int y = fsnow->y - fsnow->h;
-	    XSetFillStyle( display, FallenGC, FillStippled);
-	    XSetFunction(  display, FallenGC, GXcopy);
-	    XSetForeground(display, FallenGC, SnowcPix);
-	    XSetTSOrigin(  display, FallenGC, x+fsnow->w, y+fsnow->h);
-	    XFillRectangle(display, SnowWin,  FallenGC, x,y, fsnow->w, fsnow->h);
-	    P("Fallensnow %d %d %d %d\n",x,y,fsnow->w,fsnow->h);
+	    // determine front of Santa in fsnow
+	    int xfront = global.SantaX+global.SantaWidth - fsnow->x;
+	    // determine back of Santa in fsnow, Santa can move backwards in strong wind
+	    int xback = xfront - global.SantaWidth;
+	    const int clearing = 1;
+	    float vy = -1.5*global.ActualSantaSpeed; 
+	    if(vy > 0) vy = -vy;
+	    if (vy < -100.0)
+	       vy = -100;
+	    if (global.ActualSantaSpeed > 0)
+	       GenerateFlakesFromFallen(fsnow,xfront,clearing,vy);
+	    CleanFallenArea(fsnow,xback-clearing,global.SantaWidth+2*clearing);
+	    int i;
+	    for (i=0; i<fsnow->w; i++)
+	       if (i < xfront+clearing && i>=xback-clearing)
+		  fsnow->acth[i] = 0;
+	    XFlush(global.display);
 	 }
       }
+      CreateSurfaceFromFallen(fsnow);
+      // drawing is handled in fallensnow-draw
+   }
 }
 
 void GenerateFlakesFromFallen(FallenSnow *fsnow, int x, int w, float vy)
@@ -411,9 +378,9 @@ void GenerateFlakesFromFallen(FallenSnow *fsnow, int x, int w, float vy)
    if (ifirst > fsnow->w) ifirst = fsnow->w;
    int ilast  = x+w; if(ilast < 0) ilast = 0;
    if (ilast > fsnow->w) ilast = fsnow->w;
-   P("ifirst ilast: %d %d %d %d\n",ifirst,ilast,w,w<MaxSnowFlakeWidth?w:MaxSnowFlakeWidth);
-   P("maxheight: %d maxw: %d\n",MaxSnowFlakeHeight,MaxSnowFlakeWidth);
-   //for (i=ifirst; i<ilast; i+=w<MaxSnowFlakeHeight?w:MaxSnowFlakeWidth)
+   P("ifirst ilast: %d %d %d %d\n",ifirst,ilast,w,w<global.MaxSnowFlakeWidth?w:global.MaxSnowFlakeWidth);
+   P("maxheight: %d maxw: %d\n",global.MaxSnowFlakeHeight,global.MaxSnowFlakeWidth);
+   //for (i=ifirst; i<ilast; i+=w<global.MaxSnowFlakeHeight?w:global.MaxSnowFlakeWidth)
    for (i=ifirst; i<ilast; i+=1)
    {
       int j;
@@ -423,33 +390,23 @@ void GenerateFlakesFromFallen(FallenSnow *fsnow, int x, int w, float vy)
 	 for(k=0; k<kmax; k++)
 	 {
 	    float p = 0;
-	    //if (!switches.UseGtk)
 	    p = drand48();
-	    // In X11, (switches.UseGtk!=1) we want not too much
+	    // In X11, (global.Trans!=1) we want not too much
 	    // generated flakes
 	    // Otherwize, we go for more dramatic effects
-	    // But, it appeared that, if switches.UseGtk==1, too much snow
+	    // But, it appeared that, if global.Trans==1, too much snow
 	    // is generated, choking the x server. 
 	    if (p < 0.15)
 	    {
 	       Snow *flake   = MakeFlake(-1);
-	       //flake->rx     = fsnow->x + i + 2*MaxSnowFlakeWidth*(drand48()-0.5);
-	       //flake->ry     = fsnow->y - j - MaxSnowFlakeHeight;
 	       flake->rx     = fsnow->x + i + 16*(drand48()-0.5);
 	       flake->ry     = fsnow->y - j - 8;
 	       if (Flags.NoWind)
 		  flake->vx     = 0;
 	       else
-		  flake->vx      = NewWind/8;
+		  flake->vx      = global.NewWind/8;
 	       flake->vy         = vy;
 	       flake->cyclic     = 0;
-	       //if (switches.UseGtk && drand48() > 0.25)
-	       //if(drand48() > 0.25)
-	       if(0)  // next {} is not needed, it seems now
-	       {
-		  fluffify(flake,0.7);
-		  //flake->ry += 2*MaxSnowFlakeHeight*drand48();
-	       }
 	    }
 	 }
       }
@@ -460,14 +417,11 @@ void EraseFallenPixel(FallenSnow *fsnow, int x)
 {
    if(fsnow->acth[x] > 0)
    {
-      if(!switches.UseGtk)
+      if(!global.IsDouble)
       {
 	 int x1 = fsnow->x + x;
 	 int y1 = fsnow->y - fsnow->acth[x];
-	 if(switches.Trans|Flags.UseBG)
-	    XDrawPoint(display, SnowWin, EFallenGC, x1, y1);
-	 else
-	    XClearArea(display, SnowWin, x1 , y1, 1, 1, switches.Exposures);     
+	 myXClearArea(global.display, global.SnowWin, x1 , y1, 1, 1, global.xxposures);     
       }
       fsnow->acth[x]--;
    }
@@ -475,13 +429,14 @@ void EraseFallenPixel(FallenSnow *fsnow, int x)
 
 void InitFallenSnow()
 {
-   while (FsnowFirst)
-      PopFallenSnow(&FsnowFirst);
+   while (global.FsnowFirst)
+      PopFallenSnow(&global.FsnowFirst);
    // create fallensnow on bottom of screen:
    WinInfo *NullWindow = (WinInfo *)malloc(sizeof(WinInfo));
    memset(NullWindow,0,sizeof(WinInfo));
 
-   PushFallenSnow(&FsnowFirst, NullWindow, 0, SnowWinHeight, SnowWinWidth, MaxScrSnowDepth);
+   PushFallenSnow(&global.FsnowFirst, NullWindow, 0, global.SnowWinHeight, global.SnowWinWidth, global.MaxScrSnowDepth);
+   free(NullWindow);
 }
 
 // removes some fallen snow from fsnow, w pixels. If fallensnowheight < h: no removal
@@ -494,16 +449,15 @@ void UpdateFallenSnowWithWind(FallenSnow *fsnow, int w, int h)
       if(fsnow->acth[i] > h)
       {
 	 // animation of blown off snow
-	 if (!Flags.NoWind && Wind != 0 && drand48() > 0.5)
+	 if (!Flags.NoWind && global.Wind != 0 && drand48() > 0.5)
 	 {
 	    int j, jmax = BlowOff();
-	    //P("%d\n",jmax);
 	    for (j=0; j< jmax; j++)
 	    {
 	       Snow *flake       = MakeFlake(0);
 	       flake->rx         = fsnow->x + i;
-	       flake->ry         = fsnow->y - fsnow->acth[i] - drand48()*8;// randint(MaxSnowFlakeWidth);
-	       flake->vx         = fsignf(NewWind)*WindMax;
+	       flake->ry         = fsnow->y - fsnow->acth[i] - drand48()*8;
+	       flake->vx         = fsignf(global.NewWind)*global.WindMax;
 	       flake->vy         = -5;
 	       flake->cyclic     = (fsnow->win.id == 0); // not cyclic for Windows, cyclic for bottom
 	       P("%d:\n",counter++);
@@ -515,10 +469,10 @@ void UpdateFallenSnowWithWind(FallenSnow *fsnow, int w, int h)
 
 void SetMaxScreenSnowDepth()
 {
-   MaxScrSnowDepth = Flags.MaxScrSnowDepth;
-   if (MaxScrSnowDepth> (SnowWinHeight-SNOWFREE)) {
-      printf("** Maximum snow depth set to %d\n", SnowWinHeight-SNOWFREE);
-      MaxScrSnowDepth = SnowWinHeight-SNOWFREE;
+   global.MaxScrSnowDepth = Flags.MaxScrSnowDepth;
+   if (global.MaxScrSnowDepth> (global.SnowWinHeight-SNOWFREE)) {
+      printf("** Maximum snow depth set to %d\n", global.SnowWinHeight-SNOWFREE);
+      global.MaxScrSnowDepth = global.SnowWinHeight-SNOWFREE;
    }
 }
 
@@ -535,7 +489,7 @@ void UpdateFallenSnowPartial(FallenSnow *fsnow, int x, int w)
    if (imax > fsnow->w) imax = fsnow->w;
    int i, k;
    k = 0;
-   typeof(fsnow->acth[0]) *old;
+   short int *old;
    // old will contain the acth values, corresponding with x-1..x+w (including)
    old = (short int *)malloc(sizeof(*old)*(w+2));
    for (i=imin-1; i<=imax; i++) 
@@ -586,7 +540,6 @@ void UpdateFallenSnowPartial(FallenSnow *fsnow, int x, int w)
       k++;
    }
    free(old);
-   fsnow->clean = 0;
 }
 
 int HandleFallenSnow(FallenSnow *fsnow)
@@ -597,7 +550,7 @@ int HandleFallenSnow(FallenSnow *fsnow)
       return 0;
    if (!fsnow->win.sticky)
    {
-      if (fsnow->win.ws != CWorkSpace)
+      if (fsnow->win.ws != global.CWorkSpace)
 	 return 0;
    }
    return !Flags.NoKeepSWin;
