@@ -132,22 +132,6 @@ int HandleFlags(int argc, char*argv[])
 	    PrintVersion();
 	    return 1;
 	 }
-	 else if (!strcmp(arg, "-wantwindow"))
-	 {
-	    P("setting wantwindow\n");
-	    checkax;
-	    char *v = argv[++ax];
-	    if (!strcmp(v,"default"))
-	       Flags.WantWindow = UW_DEFAULT;
-	    else if (!strcmp(v,"transparent"))
-	       Flags.WantWindow = UW_TRANSPARENT;
-	    else
-	    {
-	       printf("** Invalid value for -wantwindow: %s\n",v);
-	       printf("** Expected on of: default, transparent\n");
-	       return -1;
-	    }
-	 }
 	 else if (strcmp(arg, "-nokeepsnow") == 0) 
 	 {
 	    Flags.NoKeepSnow = 1;
@@ -176,6 +160,7 @@ int HandleFlags(int argc, char*argv[])
 	 handle_ia(-blowofffactor       ,BlowOffFactor                    );
 	 handle_ia(-checkgtk            ,CheckGtk                         );
 	 handle_ia(-cpuload             ,CpuLoad                          );
+	 handle_ia(-doublebuffer        ,UseDouble                        );
 	 handle_ia(-flakecountmax       ,FlakeCountMax                    );
 	 handle_ia(-id                  ,WindowId                         );
 	 handle_ia(-window-id           ,WindowId                         );
@@ -185,13 +170,13 @@ int HandleFlags(int argc, char*argv[])
 	 handle_ia(-moonsize            ,MoonSize                         );
 	 handle_ia(-halo                ,Halo                             );
 	 handle_ia(-halobrightness      ,HaloBright                       );
-	 handle_ia(-movewindow          ,MoveWindow                       );
 	 handle_im(-offsets             ,OffsetS                          );
 	 handle_im(-offsetw             ,OffsetW                          );
 	 handle_im(-offsetx             ,OffsetX                          );
 	 handle_im(-offsety             ,OffsetY                          );
 	 handle_ia(-santa               ,SantaSize                        );
 	 handle_ia(-santaspeedfactor    ,SantaSpeedFactor                 );
+	 handle_ia(-scale               ,Scale                            );
 	 handle_ia(-snowflakes          ,SnowFlakesFactor                 );
 	 handle_ia(-snowspeedfactor     ,SnowSpeedFactor                  );
 	 handle_ia(-snowsize            ,SnowSize                         );
@@ -201,13 +186,11 @@ int HandleFlags(int argc, char*argv[])
 	 handle_ia(-theme               ,ThemeXsnow                       );
 	 handle_ia(-treefill            ,TreeFill                         );
 	 handle_ia(-trees               ,DesiredNumberOfTrees             );
-	 handle_ia(-usebg               ,UseBG                            );
 	 handle_ia(-whirlfactor         ,WhirlFactor                      );
 	 handle_ia(-windtimer           ,WindTimer                        );
 	 handle_ia(-wsnowdepth          ,MaxWinSnowDepth                  );
 
 
-	 handle_is(-bg                  ,BGColor                          );
 	 handle_is(-display             ,DisplayName                      );
 	 handle_is(-sc                  ,SnowColor                        );
 	 handle_is(-tc                  ,TreeColor                        );
@@ -215,11 +198,9 @@ int HandleFlags(int argc, char*argv[])
 
 	 handle_iv(-above               ,BelowAll                 ,0      );
 	 handle_iv(-defaults            ,Defaults                 ,1      );
-	 handle_iv(-exposures           ,Exposures                ,True   );
 	 handle_iv(-noblowsnow          ,BlowSnow                 ,0      );
 	 handle_iv(-blowsnow            ,BlowSnow                 ,1      );
 	 handle_iv(-noconfig            ,NoConfig                 ,1      );
-	 handle_iv(-noexposures         ,Exposures                ,False  );
 	 handle_iv(-fluffy              ,NoFluffy                 ,0      );
 	 handle_iv(-hidemenu            ,HideMenu                 ,1      );
 	 handle_iv(-nofluffy            ,NoFluffy                 ,1      );
