@@ -19,10 +19,14 @@
 #-# 
 */
 #pragma once
+
 #include <X11/xpm.h>
+#include <gtk/gtk.h>
+
 extern int iXpmCreatePixmapFromData(Display *display, Drawable d, 
       const char **data, Pixmap *p,Pixmap *s, XpmAttributes *attr, int flop);
-extern Region regionfromxpm(const char **data, int flop);
+extern Region regionfromxpm(const char **data, int flop, float scale);
+cairo_region_t *gregionfromxpm(const char **data, int flop, float scale);
 
 extern void xpm_set_color(char **data, char ***out, int *lines, const char *color);
 extern void xpm_destroy(char **data);
