@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020 Willem Vermin
+#-# 	      2019,2020,2021 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -46,14 +46,23 @@
    */
 /* single nearest neighbor search written by Tamas Nepusz <tamas@cs.rhul.ac.uk> */
 
+#define USE_LIST_NODE_ALLOCATOR
+#define NO_ALLOCA
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
 #include <stdio.h>
 #include <stdlib.h>
+#ifndef NO_ALLOCA
+#ifdef HAVE_ALLOCA_H
+#include <alloca.h>
+#endif
+#endif
 #include <string.h>
 #include <math.h>
+#include <assert.h>
 #include "kdtree.h"
 
 #if defined(WIN32) || defined(__WIN32__)
@@ -192,6 +201,7 @@ static int insert_rec(struct kdnode **nptr, const double *pos, void *data, int d
       if(!(node = (struct kdnode *)malloc(sizeof *node))) {
 	 return -1;
       }
+      assert(dim>0);
       if(!(node->pos = (double *)malloc(dim * sizeof *node->pos))) {
 	 free(node);
 	 return -1;
@@ -232,6 +242,7 @@ int kd_insertf(struct kdtree *tree, const float *pos, void *data)
    static double sbuf[16];
    double *bptr, *buf = NULL;
    int res, dim = tree->dim;
+   assert(dim>0);
 
    if(dim > 16) {
 #ifndef NO_ALLOCA
@@ -481,6 +492,7 @@ struct kdres *kd_nearestf(struct kdtree *tree, const float *pos)
    double *bptr, *buf = NULL;
    int dim = tree->dim;
    struct kdres *res;
+   assert(dim>0);
 
    if(dim > 16) {
 #ifndef NO_ALLOCA
@@ -583,6 +595,7 @@ struct kdres *kd_nearest_rangef(struct kdtree *kd, const float *pos, float range
    double *bptr, *buf = NULL;
    int dim = kd->dim;
    struct kdres *res;
+   assert(dim>0);
 
    if(dim > 16) {
 #ifndef NO_ALLOCA
@@ -712,6 +725,7 @@ void *kd_res_item_data(struct kdres *set)
 /* ---- hyperrectangle helpers ---- */
 static struct kdhyperrect* hyperrect_create(int dim, const double *min, const double *max)
 {
+   assert(dim>0);
    size_t size = dim * sizeof(double);
    struct kdhyperrect* rect = NULL;
 
