@@ -28,17 +28,16 @@
 #include "utils.h"
 #include "clocks.h"
 #include "xsnow.h"
-#include "varia.h"
 #include "flags.h"
 
-static int do_loadmeasure(gpointer data);
+static int do_loadmeasure(void *);
 
 int loadmeasure_ui()
 {
    // nothing to do
    return 0;
 }
-void loadmeasure_draw(UNUSED cairo_t *cr)
+void loadmeasure_draw()
 {
    // nothing to draw
    //
@@ -46,19 +45,19 @@ void loadmeasure_draw(UNUSED cairo_t *cr)
 
 void loadmeasure_init()
 {
-   add_to_mainloop(PRIORITY_DEFAULT, time_measure, do_loadmeasure, NULL);
+   add_to_mainloop(PRIORITY_DEFAULT, time_measure, do_loadmeasure);
 }
 
 // changes background color of ui if load to high
-int do_loadmeasure(UNUSED gpointer data)
+int do_loadmeasure(void *d)
 {
    double tnow = wallclock();
    static double tprev;
    static int count  = 0;
    static int status = 0;
 
-   if (tnow-tprev > 1.1*time_measure)
-   //if (tnow-tprev > 0.9*time_measure)
+   if (tnow-tprev > 1.2*time_measure)
+   //if (tnow-tprev > 0.9*time_measure)   // for testing purposes
       count++;
    else 
       count --;
@@ -91,4 +90,5 @@ int do_loadmeasure(UNUSED gpointer data)
    }
    tprev = tnow;
    return TRUE;
+   (void)d;
 }
