@@ -20,13 +20,7 @@
  */
 #pragma once
 
-typedef struct _MeteoMap {
-   int x1,x2,y1,y2,active;
-   double starttime;
-   GC gc,egc;
-   Region r;
-} MeteoMap;
-
+#include <gtk/gtk.h>
 
 extern void meteo_init(void);
 extern void meteo_ui(void);
