@@ -1,4 +1,3 @@
-#pragma once
 /* -copyright-
 #-# 
 #-# xsnow: let it snow on your desktop
@@ -19,28 +18,12 @@
 #-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #-# 
  */
+#pragma once
 
-#include "xsnow.h"
 #include <gtk/gtk.h>
 
-typedef struct Treeinfo { 
-   int x;                    // x position
-   int y;                    // y position
-#ifdef NO_USE_BITS 
-   unsigned int type  ;      // type (TreeType, -treetype)
-   unsigned int rev   ;      // reversed
-#else
-   unsigned int type: 8;      // type (TreeType, -treetype)
-   unsigned int rev : 1;      // reversed
-#endif
-} Treeinfo;
-
 extern void scenery_init(void);
-extern void     scenery_ui(void);
-extern void     EraseTrees(void);
-extern void     scenery_set_gc(void);
-extern int      scenery_draw(cairo_t *cr);
-
-extern int      KillTrees;  // 1: signal to trees to kill themselves
-extern Region   TreeRegion;
+extern void scenery_ui(void);
+extern void EraseTrees(void);
+extern int  scenery_draw(cairo_t *cr);
 
