@@ -19,7 +19,20 @@
 #-# 
 */
 #pragma once
-#define VERSION "3.2.2"
+
+// VERSION is defined via the AC_INIT line in configure.ac
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#else
+#ifndef VERSION
+#define VERSION "unknown"
+#endif
+#ifndef PACKAGE_STRING
+#define PACKAGE_STRING "xsnow " VERSION
+#endif
+#endif
+
 #define VERSIONBY \
    "December 14th 2001 by Rick Jansen \n" \
-   "January 2021 by Willem Vermin"
+   "August 2021 by Willem Vermin"
